"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_analyzer_management_service.proto')
_sym_db = _symbol_database.Default()
from .analyzing import analyzer_info_pb2 as analyzing_dot_analyzer__info__pb2
from .connection import connection_state_pb2 as connection_dot_connection__state__pb2
from .analyzing import analyzer_settings_pb2 as analyzing_dot_analyzer__settings__pb2
from . import ares_struct_pb2 as ares__struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ares_analyzer_management_service.proto\x12\rares.services\x1a\x1danalyzing/analyzer_info.proto\x1a!connection/connection_state.proto\x1a!analyzing/analyzer_settings.proto\x1a\x11ares_struct.proto\x1a\x1bgoogle/protobuf/empty.proto"T\n\x17GetAllAnalyzersResponse\x129\n\tanalyzers\x18\x01 \x03(\x0b2&.ares.datamodel.analyzing.AnalyzerInfo"5\n\x18AddRemoteAnalyzerRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t"o\n\x19AddRemoteAnalyzerResponse\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x1a\n\rerror_message\x18\x03 \x01(\tH\x00\x88\x01\x01B\x10\n\x0e_error_message"h\n\x1bUpdateRemoteAnalyzerRequest\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03url\x18\x03 \x01(\tH\x01\x88\x01\x01B\x07\n\x05_nameB\x06\n\x04_url"]\n\x1cUpdateRemoteAnalyzerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x00\x88\x01\x01B\x10\n\x0e_error_message"q\n\x1bRemoveRemoteAnalyzerRequest\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x1a\n\rerror_message\x18\x03 \x01(\tH\x00\x88\x01\x01B\x10\n\x0e_error_message"*\n\x13AnalyzerInfoRequest\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t"L\n\x14AnalyzerInfoResponse\x124\n\x04info\x18\x01 \x01(\x0b2&.ares.datamodel.analyzing.AnalyzerInfo".\n\x17AnalyzerSettingsRequest\x12\x13\n\x0banalyzer_id\x18\x01 \x01(\t2\x90\x06\n\x1dAresAnalyzerManagementService\x12]\n\x08GetState\x12\'.ares.datamodel.connection.StateRequest\x1a(.ares.datamodel.connection.StateResponse\x12R\n\x07GetInfo\x12".ares.services.AnalyzerInfoRequest\x1a#.ares.services.AnalyzerInfoResponse\x12Y\n\x13SetAnalyzerSettings\x12*.ares.datamodel.analyzing.AnalyzerSettings\x1a\x16.google.protobuf.Empty\x12Y\n\x13GetAnalyzerSettings\x12&.ares.services.AnalyzerSettingsRequest\x1a\x1a.ares.datamodel.AresStruct\x12Q\n\x0fGetAllAnalyzers\x12\x16.google.protobuf.Empty\x1a&.ares.services.GetAllAnalyzersResponse\x12f\n\x11AddRemoteAnalyzer\x12\'.ares.services.AddRemoteAnalyzerRequest\x1a(.ares.services.AddRemoteAnalyzerResponse\x12o\n\x14UpdateRemoteAnalyzer\x12*.ares.services.UpdateRemoteAnalyzerRequest\x1a+.ares.services.UpdateRemoteAnalyzerResponse\x12Z\n\x14RemoveRemoteAnalyzer\x12*.ares.services.RemoveRemoteAnalyzerRequest\x1a\x16.google.protobuf.Emptyb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_analyzer_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_GETALLANALYZERSRESPONSE']._serialized_start = 206
    _globals['_GETALLANALYZERSRESPONSE']._serialized_end = 290
    _globals['_ADDREMOTEANALYZERREQUEST']._serialized_start = 292
    _globals['_ADDREMOTEANALYZERREQUEST']._serialized_end = 345
    _globals['_ADDREMOTEANALYZERRESPONSE']._serialized_start = 347
    _globals['_ADDREMOTEANALYZERRESPONSE']._serialized_end = 458
    _globals['_UPDATEREMOTEANALYZERREQUEST']._serialized_start = 460
    _globals['_UPDATEREMOTEANALYZERREQUEST']._serialized_end = 564
    _globals['_UPDATEREMOTEANALYZERRESPONSE']._serialized_start = 566
    _globals['_UPDATEREMOTEANALYZERRESPONSE']._serialized_end = 659
    _globals['_REMOVEREMOTEANALYZERREQUEST']._serialized_start = 661
    _globals['_REMOVEREMOTEANALYZERREQUEST']._serialized_end = 774
    _globals['_ANALYZERINFOREQUEST']._serialized_start = 776
    _globals['_ANALYZERINFOREQUEST']._serialized_end = 818
    _globals['_ANALYZERINFORESPONSE']._serialized_start = 820
    _globals['_ANALYZERINFORESPONSE']._serialized_end = 896
    _globals['_ANALYZERSETTINGSREQUEST']._serialized_start = 898
    _globals['_ANALYZERSETTINGSREQUEST']._serialized_end = 944
    _globals['_ARESANALYZERMANAGEMENTSERVICE']._serialized_start = 947
    _globals['_ARESANALYZERMANAGEMENTSERVICE']._serialized_end = 1731


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'analyzing/analyzer_info.proto')
_sym_db = _symbol_database.Default()
from ..analyzing import analyzer_capabilities_pb2 as analyzing_dot_analyzer__capabilities__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1danalyzing/analyzer_info.proto\x12\x18ares.datamodel.analyzing\x1a%analyzing/analyzer_capabilities.proto"\xeb\x01\n\x0cAnalyzerInfo\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x18\n\x0bdescription\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x0f\n\x07version\x18\x05 \x01(\t\x12D\n\x0ccapabilities\x18\x06 \x01(\x0b2..ares.datamodel.analyzing.AnalyzerCapabilities\x12\x10\n\x03url\x18\x07 \x01(\tH\x02\x88\x01\x01B\x0c\n\n_unique_idB\x0e\n\x0c_descriptionB\x06\n\x04_urlb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analyzing.analyzer_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ANALYZERINFO']._serialized_start = 99
    _globals['_ANALYZERINFO']._serialized_end = 334


from google.protobuf import any_pb2 as _any_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceConfig(_message.Message):
    __slots__ = ("unique_id", "device_name", "device_type", "config_data")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    DEVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    DEVICE_TYPE_FIELD_NUMBER: _ClassVar[int]
    CONFIG_DATA_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    device_name: str
    device_type: str
    config_data: _any_pb2.Any
    def __init__(self, unique_id: _Optional[str] = ..., device_name: _Optional[str] = ..., device_type: _Optional[str] = ..., config_data: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'templates/command_metadata.proto')
_sym_db = _symbol_database.Default()
from ..templates import parameter_metadata_pb2 as templates_dot_parameter__metadata__pb2
from ..templates import output_metadata_pb2 as templates_dot_output__metadata__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n templates/command_metadata.proto\x12\x18ares.datamodel.templates\x1a"templates/parameter_metadata.proto\x1a\x1ftemplates/output_metadata.proto"\x8f\x02\n\x0fCommandMetadata\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0bdescription\x18\x03 \x01(\t\x12\x11\n\tdevice_id\x18\x04 \x01(\t\x12A\n\x0foutput_metadata\x18\x05 \x01(\x0b2(.ares.datamodel.templates.OutputMetadata\x12H\n\x13parameter_metadatas\x18\x06 \x03(\x0b2+.ares.datamodel.templates.ParameterMetadata\x12\x13\n\x0bdevice_type\x18\x07 \x01(\tB\x0c\n\n_unique_idb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'templates.command_metadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_COMMANDMETADATA']._serialized_start = 132
    _globals['_COMMANDMETADATA']._serialized_end = 403


from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExecutionState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNDEFINED: _ClassVar[ExecutionState]
    SUCCEEDED: _ClassVar[ExecutionState]
    WAITING: _ClassVar[ExecutionState]
    AWAITING_USER: _ClassVar[ExecutionState]
    RUNNING: _ClassVar[ExecutionState]
    PAUSED: _ClassVar[ExecutionState]
    FAILED: _ClassVar[ExecutionState]

class AnalysisState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NO_ANALYSIS_REQUIRED: _ClassVar[AnalysisState]
    ANALYSIS_INCOMPLETE: _ClassVar[AnalysisState]
    ANALYSIS_IN_PROGRESS: _ClassVar[AnalysisState]
    ANALYSIS_COMPLETE: _ClassVar[AnalysisState]
    ANALYSIS_ERROR: _ClassVar[AnalysisState]

class PlannerState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NO_PLANNING_REQUIRED: _ClassVar[PlannerState]
    PLANNING_INCOMPLETE: _ClassVar[PlannerState]
    PLANNING_IN_PROGRESS: _ClassVar[PlannerState]
    PLANNING_COMPLETE: _ClassVar[PlannerState]
    PLANNING_ERROR: _ClassVar[PlannerState]
UNDEFINED: ExecutionState
SUCCEEDED: ExecutionState
WAITING: ExecutionState
AWAITING_USER: ExecutionState
RUNNING: ExecutionState
PAUSED: ExecutionState
FAILED: ExecutionState
NO_ANALYSIS_REQUIRED: AnalysisState
ANALYSIS_INCOMPLETE: AnalysisState
ANALYSIS_IN_PROGRESS: AnalysisState
ANALYSIS_COMPLETE: AnalysisState
ANALYSIS_ERROR: AnalysisState
NO_PLANNING_REQUIRED: PlannerState
PLANNING_INCOMPLETE: PlannerState
PLANNING_IN_PROGRESS: PlannerState
PLANNING_COMPLETE: PlannerState
PLANNING_ERROR: PlannerState

class CampaignExecutionStatus(_message.Message):
    __slots__ = ("campaign_id", "state", "experiment_execution_statuses", "analysis_state", "planner_state")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    EXPERIMENT_EXECUTION_STATUSES_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_STATE_FIELD_NUMBER: _ClassVar[int]
    PLANNER_STATE_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    state: ExecutionState
    experiment_execution_statuses: _containers.RepeatedCompositeFieldContainer[ExperimentExecutionStatus]
    analysis_state: AnalysisState
    planner_state: PlannerState
    def __init__(self, campaign_id: _Optional[str] = ..., state: _Optional[_Union[ExecutionState, str]] = ..., experiment_execution_statuses: _Optional[_Iterable[_Union[ExperimentExecutionStatus, _Mapping]]] = ..., analysis_state: _Optional[_Union[AnalysisState, str]] = ..., planner_state: _Optional[_Union[PlannerState, str]] = ...) -> None: ...

class CampaignExecutionState(_message.Message):
    __slots__ = ("campaign_id", "state", "analysis_state", "planner_state")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    ANALYSIS_STATE_FIELD_NUMBER: _ClassVar[int]
    PLANNER_STATE_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    state: ExecutionState
    analysis_state: AnalysisState
    planner_state: PlannerState
    def __init__(self, campaign_id: _Optional[str] = ..., state: _Optional[_Union[ExecutionState, str]] = ..., analysis_state: _Optional[_Union[AnalysisState, str]] = ..., planner_state: _Optional[_Union[PlannerState, str]] = ...) -> None: ...

class ExperimentExecutionStatus(_message.Message):
    __slots__ = ("experiment_id", "step_execution_statuses")
    EXPERIMENT_ID_FIELD_NUMBER: _ClassVar[int]
    STEP_EXECUTION_STATUSES_FIELD_NUMBER: _ClassVar[int]
    experiment_id: str
    step_execution_statuses: _containers.RepeatedCompositeFieldContainer[StepExecutionStatus]
    def __init__(self, experiment_id: _Optional[str] = ..., step_execution_statuses: _Optional[_Iterable[_Union[StepExecutionStatus, _Mapping]]] = ...) -> None: ...

class CampaignStartupStatus(_message.Message):
    __slots__ = ("campaign_id", "startup_execution_statuses")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    STARTUP_EXECUTION_STATUSES_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    startup_execution_statuses: _containers.RepeatedCompositeFieldContainer[StepExecutionStatus]
    def __init__(self, campaign_id: _Optional[str] = ..., startup_execution_statuses: _Optional[_Iterable[_Union[StepExecutionStatus, _Mapping]]] = ...) -> None: ...

class CampaignCloseoutStatus(_message.Message):
    __slots__ = ("campaign_id", "closeout_execution_statuses")
    CAMPAIGN_ID_FIELD_NUMBER: _ClassVar[int]
    CLOSEOUT_EXECUTION_STATUSES_FIELD_NUMBER: _ClassVar[int]
    campaign_id: str
    closeout_execution_statuses: _containers.RepeatedCompositeFieldContainer[StepExecutionStatus]
    def __init__(self, campaign_id: _Optional[str] = ..., closeout_execution_statuses: _Optional[_Iterable[_Union[StepExecutionStatus, _Mapping]]] = ...) -> None: ...

class StepExecutionStatus(_message.Message):
    __slots__ = ("step_id", "step_name", "command_execution_statuses")
    STEP_ID_FIELD_NUMBER: _ClassVar[int]
    STEP_NAME_FIELD_NUMBER: _ClassVar[int]
    COMMAND_EXECUTION_STATUSES_FIELD_NUMBER: _ClassVar[int]
    step_id: str
    step_name: str
    command_execution_statuses: _containers.RepeatedCompositeFieldContainer[CommandExecutionStatus]
    def __init__(self, step_id: _Optional[str] = ..., step_name: _Optional[str] = ..., command_execution_statuses: _Optional[_Iterable[_Union[CommandExecutionStatus, _Mapping]]] = ...) -> None: ...

class CommandExecutionStatus(_message.Message):
    __slots__ = ("command_id", "command_name", "device_name", "state")
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_NAME_FIELD_NUMBER: _ClassVar[int]
    DEVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    command_id: str
    command_name: str
    device_name: str
    state: ExecutionState
    def __init__(self, command_id: _Optional[str] = ..., command_name: _Optional[str] = ..., device_name: _Optional[str] = ..., state: _Optional[_Union[ExecutionState, str]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VariableType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    VAR_UNSPECIFIED: _ClassVar[VariableType]
    CAMPAIGN_RESULT_PATH: _ClassVar[VariableType]
    EXPERIMENT_RESULT_PATH: _ClassVar[VariableType]
    PREVIOUS_EXPERIMENT_PATH: _ClassVar[VariableType]
    CAMPAIGN_MISC_FOLDER: _ClassVar[VariableType]
    CAMPAIGN_STARTUP_FOLDER: _ClassVar[VariableType]
VAR_UNSPECIFIED: VariableType
CAMPAIGN_RESULT_PATH: VariableType
EXPERIMENT_RESULT_PATH: VariableType
PREVIOUS_EXPERIMENT_PATH: VariableType
CAMPAIGN_MISC_FOLDER: VariableType
CAMPAIGN_STARTUP_FOLDER: VariableType

class VariableAllocation(_message.Message):
    __slots__ = ("unqiue_id", "variable_type", "parameter_name")
    UNQIUE_ID_FIELD_NUMBER: _ClassVar[int]
    VARIABLE_TYPE_FIELD_NUMBER: _ClassVar[int]
    PARAMETER_NAME_FIELD_NUMBER: _ClassVar[int]
    unqiue_id: str
    variable_type: VariableType
    parameter_name: str
    def __init__(self, unqiue_id: _Optional[str] = ..., variable_type: _Optional[_Union[VariableType, str]] = ..., parameter_name: _Optional[str] = ...) -> None: ...



import ares_data_schema_pb2 as _ares_data_schema_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceCommandDescriptor(_message.Message):
    __slots__ = ("name", "description", "input_schema", "output_schema")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    INPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    input_schema: _ares_data_schema_pb2.AresDataSchema
    output_schema: _ares_data_schema_pb2.AresDataSchema
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., input_schema: _Optional[_Union[_ares_data_schema_pb2.AresDataSchema, _Mapping]] = ..., output_schema: _Optional[_Union[_ares_data_schema_pb2.AresDataSchema, _Mapping]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'planning/planner_allocation.proto')
_sym_db = _symbol_database.Default()
from ..planning import planner_service_info_pb2 as planning_dot_planner__service__info__pb2
from ..templates import parameter_metadata_pb2 as templates_dot_parameter__metadata__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!planning/planner_allocation.proto\x12\x17ares.datamodel.planning\x1a#planning/planner_service_info.proto\x1a"templates/parameter_metadata.proto"\xb7\x01\n\x11PlannerAllocation\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12<\n\x07planner\x18\x02 \x01(\x0b2+.ares.datamodel.planning.PlannerServiceInfo\x12>\n\tparameter\x18\x03 \x01(\x0b2+.ares.datamodel.templates.ParameterMetadataB\x0c\n\n_unique_idb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'planning.planner_allocation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_PLANNERALLOCATION']._serialized_start = 136
    _globals['_PLANNERALLOCATION']._serialized_end = 319


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_planner_management_service.proto')
_sym_db = _symbol_database.Default()
from .planning import planner_service_info_pb2 as planning_dot_planner__service__info__pb2
from .planning import planner_settings_pb2 as planning_dot_planner__settings__pb2
from .planning import manual_planner_pb2 as planning_dot_manual__planner__pb2
from .connection import connection_state_pb2 as connection_dot_connection__state__pb2
from . import ares_struct_pb2 as ares__struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ares_planner_management_service.proto\x12\rares.services\x1a#planning/planner_service_info.proto\x1a\x1fplanning/planner_settings.proto\x1a\x1dplanning/manual_planner.proto\x1a!connection/connection_state.proto\x1a\x11ares_struct.proto\x1a\x1bgoogle/protobuf/empty.proto"(\n\x12PlannerInfoRequest\x12\x12\n\nplanner_id\x18\x01 \x01(\t"P\n\x13PlannerInfoResponse\x129\n\x04info\x18\x01 \x01(\x0b2+.ares.datamodel.planning.PlannerServiceInfo",\n\x16PlannerSettingsRequest\x12\x12\n\nplanner_id\x18\x01 \x01(\t"W\n\x16GetAllPlannersResponse\x12=\n\x08planners\x18\x01 \x03(\x0b2+.ares.datamodel.planning.PlannerServiceInfo"C\n\x11AddPlannerRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x07address\x18\x02 \x01(\tH\x00\x88\x01\x01B\n\n\x08_address"S\n\x12AddPlannerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x00\x88\x01\x01B\x10\n\x0e_error_message"`\n\x14UpdatePlannerRequest\x12\x12\n\nplanner_id\x18\x01 \x01(\t\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03url\x18\x03 \x01(\tH\x01\x88\x01\x01B\x07\n\x05_nameB\x06\n\x04_url"V\n\x15UpdatePlannerResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x00\x88\x01\x01B\x10\n\x0e_error_message"*\n\x14RemovePlannerRequest\x12\x12\n\nplanner_id\x18\x01 \x01(\t2\xd2\x07\n\x1cAresPlannerManagementService\x12]\n\x08GetState\x12\'.ares.datamodel.connection.StateRequest\x1a(.ares.datamodel.connection.StateResponse\x12P\n\x07GetInfo\x12!.ares.services.PlannerInfoRequest\x1a".ares.services.PlannerInfoResponse\x12V\n\x12SetPlannerSettings\x12(.ares.datamodel.planning.PlannerSettings\x1a\x16.google.protobuf.Empty\x12W\n\x12GetPlannerSettings\x12%.ares.services.PlannerSettingsRequest\x1a\x1a.ares.datamodel.AresStruct\x12W\n\x11SeedManualPlanner\x12*.ares.datamodel.planning.ManualPlannerSeed\x1a\x16.google.protobuf.Empty\x12c\n\x14GetManualPlannerSeed\x12\x16.google.protobuf.Empty\x1a3.ares.datamodel.planning.ManualPlannerSetCollection\x12D\n\x12ResetManualPlanner\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12O\n\x0eGetAllPlanners\x12\x16.google.protobuf.Empty\x1a%.ares.services.GetAllPlannersResponse\x12Q\n\nAddPlanner\x12 .ares.services.AddPlannerRequest\x1a!.ares.services.AddPlannerResponse\x12Z\n\rUpdatePlanner\x12#.ares.services.UpdatePlannerRequest\x1a$.ares.services.UpdatePlannerResponse\x12L\n\rRemovePlanner\x12#.ares.services.RemovePlannerRequest\x1a\x16.google.protobuf.Emptyb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_planner_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_PLANNERINFOREQUEST']._serialized_start = 240
    _globals['_PLANNERINFOREQUEST']._serialized_end = 280
    _globals['_PLANNERINFORESPONSE']._serialized_start = 282
    _globals['_PLANNERINFORESPONSE']._serialized_end = 362
    _globals['_PLANNERSETTINGSREQUEST']._serialized_start = 364
    _globals['_PLANNERSETTINGSREQUEST']._serialized_end = 408
    _globals['_GETALLPLANNERSRESPONSE']._serialized_start = 410
    _globals['_GETALLPLANNERSRESPONSE']._serialized_end = 497
    _globals['_ADDPLANNERREQUEST']._serialized_start = 499
    _globals['_ADDPLANNERREQUEST']._serialized_end = 566
    _globals['_ADDPLANNERRESPONSE']._serialized_start = 568
    _globals['_ADDPLANNERRESPONSE']._serialized_end = 651
    _globals['_UPDATEPLANNERREQUEST']._serialized_start = 653
    _globals['_UPDATEPLANNERREQUEST']._serialized_end = 749
    _globals['_UPDATEPLANNERRESPONSE']._serialized_start = 751
    _globals['_UPDATEPLANNERRESPONSE']._serialized_end = 837
    _globals['_REMOVEPLANNERREQUEST']._serialized_start = 839
    _globals['_REMOVEPLANNERREQUEST']._serialized_end = 881
    _globals['_ARESPLANNERMANAGEMENTSERVICE']._serialized_start = 884
    _globals['_ARESPLANNERMANAGEMENTSERVICE']._serialized_end = 1862


import ares_data_schema_pb2 as _ares_data_schema_pb2
from planning import planner_pb2 as _planner_pb2
import ares_data_type_pb2 as _ares_data_type_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlannerServiceCapabilities(_message.Message):
    __slots__ = ("service_name", "timeout_seconds", "available_planners", "settings_schema", "accepted_types")
    SERVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_SECONDS_FIELD_NUMBER: _ClassVar[int]
    AVAILABLE_PLANNERS_FIELD_NUMBER: _ClassVar[int]
    SETTINGS_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    ACCEPTED_TYPES_FIELD_NUMBER: _ClassVar[int]
    service_name: str
    timeout_seconds: int
    available_planners: _containers.RepeatedCompositeFieldContainer[_planner_pb2.Planner]
    settings_schema: _ares_data_schema_pb2.AresDataSchema
    accepted_types: _containers.RepeatedScalarFieldContainer[_ares_data_type_pb2.AresDataType]
    def __init__(self, service_name: _Optional[str] = ..., timeout_seconds: _Optional[int] = ..., available_planners: _Optional[_Iterable[_Union[_planner_pb2.Planner, _Mapping]]] = ..., settings_schema: _Optional[_Union[_ares_data_schema_pb2.AresDataSchema, _Mapping]] = ..., accepted_types: _Optional[_Iterable[_Union[_ares_data_type_pb2.AresDataType, str]]] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class AresUserType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    AresAdmin: _ClassVar[AresUserType]
    AresUser: _ClassVar[AresUserType]
AresAdmin: AresUserType
AresUser: AresUserType



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'limits.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0climits.proto\x12\x0eares.datamodel"_\n\x06Limits\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07minimum\x18\x02 \x01(\x02\x12\x0f\n\x07maximum\x18\x03 \x01(\x02\x12\r\n\x05index\x18\x04 \x01(\x03B\x0c\n\n_unique_idb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'limits_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_LIMITS']._serialized_start = 32
    _globals['_LIMITS']._serialized_end = 127


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'device/remote/ares_remote_device_service.proto')
_sym_db = _symbol_database.Default()
from ... import ares_struct_pb2 as ares__struct__pb2
from ...device import device_status_pb2 as device_dot_device__status__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from ... import ares_data_schema_pb2 as ares__data__schema__pb2
from ...device import device_command_descriptor_pb2 as device_dot_device__command__descriptor__pb2
from ...device import device_execution_result_pb2 as device_dot_device__execution__result__pb2
from ...device import device_polling_settings_pb2 as device_dot_device__polling__settings__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.device/remote/ares_remote_device_service.proto\x12\x1cares.datamodel.device.remote\x1a\x11ares_struct.proto\x1a\x1adevice/device_status.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x16ares_data_schema.proto\x1a&device/device_command_descriptor.proto\x1a$device/device_execution_result.proto\x1a$device/device_polling_settings.proto"]\n\x12DeviceInfoResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x18\n\x0bdescription\x18\x03 \x01(\tH\x00\x88\x01\x01B\x0e\n\x0c_description"H\n\x16SettingsSchemaResponse\x12.\n\x06schema\x18\x01 \x01(\x0b2\x1e.ares.datamodel.AresDataSchema"G\n\x17CurrentSettingsResponse\x12,\n\x08settings\x18\x01 \x01(\x0b2\x1a.ares.datamodel.AresStruct"B\n\x12SetSettingsRequest\x12,\n\x08settings\x18\x01 \x01(\x0b2\x1a.ares.datamodel.AresStruct"T\n\x10CommandsResponse\x12@\n\x08commands\x18\x01 \x03(\x0b2..ares.datamodel.device.DeviceCommandDescriptor"b\n\x18DeviceStateStreamRequest\x12F\n\x10polling_settings\x18\x01 \x01(\x0b2,.ares.datamodel.device.DevicePollingSettings"E\n\x13StateSchemaResponse\x12.\n\x06schema\x18\x01 \x01(\x0b2\x1e.ares.datamodel.AresDataSchema"@\n\x13DeviceStateResponse\x12)\n\x05state\x18\x01 \x01(\x0b2\x1a.ares.datamodel.AresStruct"\\\n\x15ExecuteCommandRequest\x12\x14\n\x0ccommand_name\x18\x01 \x01(\t\x12-\n\targuments\x18\x02 \x01(\x0b2\x1a.ares.datamodel.AresStruct2\xaf\x08\n\x17AresRemoteDeviceService\x12^\n\x14GetOperationalStatus\x12\x16.google.protobuf.Empty\x1a..ares.datamodel.device.DeviceOperationalStatus\x12S\n\x07GetInfo\x12\x16.google.protobuf.Empty\x1a0.ares.datamodel.device.remote.DeviceInfoResponse\x12U\n\x0bGetCommands\x12\x16.google.protobuf.Empty\x1a..ares.datamodel.device.remote.CommandsResponse\x12s\n\x0eExecuteCommand\x123.ares.datamodel.device.remote.ExecuteCommandRequest\x1a,.ares.datamodel.device.DeviceExecutionResult\x12?\n\rEnterSafeMode\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12a\n\x11GetSettingsSchema\x12\x16.google.protobuf.Empty\x1a4.ares.datamodel.device.remote.SettingsSchemaResponse\x12c\n\x12GetCurrentSettings\x12\x16.google.protobuf.Empty\x1a5.ares.datamodel.device.remote.CurrentSettingsResponse\x12W\n\x0bSetSettings\x120.ares.datamodel.device.remote.SetSettingsRequest\x1a\x16.google.protobuf.Empty\x12[\n\x0eGetStateSchema\x12\x16.google.protobuf.Empty\x1a1.ares.datamodel.device.remote.StateSchemaResponse\x12U\n\x08GetState\x12\x16.google.protobuf.Empty\x1a1.ares.datamodel.device.remote.DeviceStateResponse\x12}\n\x0eGetStateStream\x126.ares.datamodel.device.remote.DeviceStateStreamRequest\x1a1.ares.datamodel.device.remote.DeviceStateResponse0\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.remote.ares_remote_device_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DEVICEINFORESPONSE']._serialized_start = 296
    _globals['_DEVICEINFORESPONSE']._serialized_end = 389
    _globals['_SETTINGSSCHEMARESPONSE']._serialized_start = 391
    _globals['_SETTINGSSCHEMARESPONSE']._serialized_end = 463
    _globals['_CURRENTSETTINGSRESPONSE']._serialized_start = 465
    _globals['_CURRENTSETTINGSRESPONSE']._serialized_end = 536
    _globals['_SETSETTINGSREQUEST']._serialized_start = 538
    _globals['_SETSETTINGSREQUEST']._serialized_end = 604
    _globals['_COMMANDSRESPONSE']._serialized_start = 606
    _globals['_COMMANDSRESPONSE']._serialized_end = 690
    _globals['_DEVICESTATESTREAMREQUEST']._serialized_start = 692
    _globals['_DEVICESTATESTREAMREQUEST']._serialized_end = 790
    _globals['_STATESCHEMARESPONSE']._serialized_start = 792
    _globals['_STATESCHEMARESPONSE']._serialized_end = 861
    _globals['_DEVICESTATERESPONSE']._serialized_start = 863
    _globals['_DEVICESTATERESPONSE']._serialized_end = 927
    _globals['_EXECUTECOMMANDREQUEST']._serialized_start = 929
    _globals['_EXECUTECOMMANDREQUEST']._serialized_end = 1021
    _globals['_ARESREMOTEDEVICESERVICE']._serialized_start = 1024
    _globals['_ARESREMOTEDEVICESERVICE']._serialized_end = 2095


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'templates/experiment_template.proto')
_sym_db = _symbol_database.Default()
from ..templates import step_template_pb2 as templates_dot_step__template__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#templates/experiment_template.proto\x12\x18ares.datamodel.templates\x1a\x1dtemplates/step_template.proto"\xd0\x02\n\x12ExperimentTemplate\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12>\n\x0estep_templates\x18\x02 \x03(\x0b2&.ares.datamodel.templates.StepTemplate\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x18\n\x0banalyzer_id\x18\x04 \x01(\tH\x01\x88\x01\x01\x12U\n\ranalyzer_maps\x18\x05 \x03(\x0b2>.ares.datamodel.templates.ExperimentTemplate.AnalyzerMapsEntry\x12\x10\n\x08resolved\x18\x06 \x01(\x08\x1a3\n\x11AnalyzerMapsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01B\x0c\n\n_unique_idB\x0e\n\x0c_analyzer_idb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'templates.experiment_template_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_EXPERIMENTTEMPLATE_ANALYZERMAPSENTRY']._loaded_options = None
    _globals['_EXPERIMENTTEMPLATE_ANALYZERMAPSENTRY']._serialized_options = b'8\x01'
    _globals['_EXPERIMENTTEMPLATE']._serialized_start = 97
    _globals['_EXPERIMENTTEMPLATE']._serialized_end = 433
    _globals['_EXPERIMENTTEMPLATE_ANALYZERMAPSENTRY']._serialized_start = 352
    _globals['_EXPERIMENTTEMPLATE_ANALYZERMAPSENTRY']._serialized_end = 403


from planning import planner_service_capabilities_pb2 as _planner_service_capabilities_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlannerServiceInfo(_message.Message):
    __slots__ = ("unique_id", "name", "type", "version", "address", "description", "capabilities")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CAPABILITIES_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    name: str
    type: str
    version: str
    address: str
    description: str
    capabilities: _planner_service_capabilities_pb2.PlannerServiceCapabilities
    def __init__(self, unique_id: _Optional[str] = ..., name: _Optional[str] = ..., type: _Optional[str] = ..., version: _Optional[str] = ..., address: _Optional[str] = ..., description: _Optional[str] = ..., capabilities: _Optional[_Union[_planner_service_capabilities_pb2.PlannerServiceCapabilities, _Mapping]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'device/device_info.proto')
_sym_db = _symbol_database.Default()
from .. import ares_data_schema_pb2 as ares__data__schema__pb2
from ..device import device_command_descriptor_pb2 as device_dot_device__command__descriptor__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18device/device_info.proto\x12\x15ares.datamodel.device\x1a\x16ares_data_schema.proto\x1a&device/device_command_descriptor.proto"\xa4\x02\n\nDeviceInfo\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x18\n\x0bdescription\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x10\n\x03url\x18\x06 \x01(\tH\x01\x88\x01\x01\x12<\n\x0fsettings_schema\x18\x07 \x01(\x0b2\x1e.ares.datamodel.AresDataSchemaH\x02\x88\x01\x01\x12@\n\x08commands\x18\x08 \x03(\x0b2..ares.datamodel.device.DeviceCommandDescriptorB\x0e\n\x0c_descriptionB\x06\n\x04_urlB\x12\n\x10_settings_schemab\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.device_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_DEVICEINFO']._serialized_start = 116
    _globals['_DEVICEINFO']._serialized_end = 408


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_notification.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17ares_notification.proto\x12\rares.services\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\'\n\x13SubscriptionRequest\x12\x10\n\x08clientId\x18\x01 \x01(\t"K\n\x11NotificationsList\x126\n\rnotifications\x18\x01 \x03(\x0b2\x1f.ares.services.AresNotification"\xa9\x01\n\x10AresNotification\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x126\n\x15notification_severity\x18\x03 \x01(\x0e2\x17.ares.services.Severity\x12-\n\ttimestamp\x18\x04 \x01(\x0b2\x1a.google.protobuf.Timestamp\x12\x0e\n\x06loiter\x18\x05 \x01(\x08*V\n\x08Severity\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05ERROR\x10\x03\x12\n\n\x06DANGER\x10\x04\x12\x0b\n\x07SUCCESS\x10\x052\xc1\x01\n\x13AresNotificationRpc\x12R\n\tSubscribe\x12".ares.services.SubscriptionRequest\x1a\x1f.ares.services.AresNotification0\x01\x12V\n\x1aGetUpdatedNotificationList\x12\x16.google.protobuf.Empty\x1a .ares.services.NotificationsListb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_notification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SEVERITY']._serialized_start = 394
    _globals['_SEVERITY']._serialized_end = 480
    _globals['_SUBSCRIPTIONREQUEST']._serialized_start = 104
    _globals['_SUBSCRIPTIONREQUEST']._serialized_end = 143
    _globals['_NOTIFICATIONSLIST']._serialized_start = 145
    _globals['_NOTIFICATIONSLIST']._serialized_end = 220
    _globals['_ARESNOTIFICATION']._serialized_start = 223
    _globals['_ARESNOTIFICATION']._serialized_end = 392
    _globals['_ARESNOTIFICATIONRPC']._serialized_start = 483
    _globals['_ARESNOTIFICATIONRPC']._serialized_end = 676


import ares_struct_pb2 as _ares_struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AnalyzerSettings(_message.Message):
    __slots__ = ("analyzer_id", "settings")
    ANALYZER_ID_FIELD_NUMBER: _ClassVar[int]
    SETTINGS_FIELD_NUMBER: _ClassVar[int]
    analyzer_id: str
    settings: _ares_struct_pb2.AresStruct
    def __init__(self, analyzer_id: _Optional[str] = ..., settings: _Optional[_Union[_ares_struct_pb2.AresStruct, _Mapping]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_automation.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from .templates import campaign_template_pb2 as templates_dot_campaign__template__pb2
from . import project_pb2 as project__pb2
from . import execution_status_messages_pb2 as execution__status__messages__pb2
from . import execution_summary_messages_pb2 as execution__summary__messages__pb2
from . import ares_campaign_tag_pb2 as ares__campaign__tag__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15ares_automation.proto\x12\rares.services\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!templates/campaign_template.proto\x1a\rproject.proto\x1a\x1fexecution_status_messages.proto\x1a execution_summary_messages.proto\x1a\x17ares_campaign_tag.proto":\n\nTagRequest\x12,\n\x03tag\x18\x01 \x01(\x0b2\x1f.ares.datamodel.AresCampaignTag"G\n\x0cTagsResponse\x127\n\x0eavailable_tags\x18\x01 \x03(\x0b2\x1f.ares.datamodel.AresCampaignTag"Z\n\x1aAddOrUpdateCampaignRequest\x12<\n\x08template\x18\x01 \x01(\x0b2*.ares.datamodel.templates.CampaignTemplate" \n\x0bRequestById\x12\x11\n\tunique_id\x18\x01 \x01(\t"M\n\x0fCampaignRequest\x12\x17\n\rcampaign_name\x18\x01 \x01(\tH\x00\x12\x13\n\tunique_id\x18\x02 \x01(\tH\x00B\x0c\n\nidentifier"+\n\x16GetAllCampaignsRequest\x12\x11\n\tfile_path\x18\x01 \x01(\t"T\n\x17GetAllCampaignsResponse\x129\n\tcampaigns\x18\x01 \x03(\x0b2&.ares.services.CampaignTemplateSummary"C\n\x17CampaignTemplateSummary\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\x15\n\rcampaign_name\x18\x02 \x01(\t"`\n\x10CampaignResponse\x12\x11\n\thas_value\x18\x01 \x01(\x08\x129\n\x05value\x18\x02 \x01(\x0b2*.ares.datamodel.templates.CampaignTemplate"b\n\x14StartCampaignRequest\x12\x12\n\nuser_notes\x18\x01 \x01(\t\x126\n\rcampaign_tags\x18\x02 \x03(\x0b2\x1f.ares.datamodel.AresCampaignTag"&\n\x0eProjectRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t"=\n\x10ProjectsResponse\x12)\n\x08projects\x18\x01 \x03(\x0b2\x17.ares.datamodel.Project"Z\n\x1fCampaignExecutionStatusResponse\x127\n\x06status\x18\x01 \x01(\x0b2\'.ares.datamodel.CampaignExecutionStatus"_\n\x1bStartStopConditionsResponse\x12@\n\x15start_stop_conditions\x18\x01 \x03(\x0b2!.ares.services.StartStopCondition"+\n\x15GetReplanRateResponse\x12\x12\n\nReplanRate\x18\x01 \x01(\x05"3\n\x12StartStopCondition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t" \n\nReplanRate\x12\x12\n\nReplanRate\x18\x01 \x01(\x05"2\n\x17NumExperimentsCondition\x12\x17\n\x0fnum_experiments\x18\x01 \x01(\r"P\n\x1fExperimentStopConditionResponse\x12\x18\n\x10active_condition\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t"A\n\x17AnalysisResultCondition\x12\x16\n\x0edesired_result\x18\x01 \x01(\x01\x12\x0e\n\x06leeway\x18\x02 \x01(\x01"\x84\x01\n+AvailableCampaignExecutionSummariesResponse\x12U\n\x1cavailable_campaign_summaries\x18\x01 \x03(\x0b2/.ares.services.CampaignExecutionSummaryMetadata"\x9b\x01\n CampaignExecutionSummaryMetadata\x12\x15\n\rcampaign_name\x18\x01 \x01(\t\x123\n\x0fcompletion_time\x18\x02 \x01(\x0b2\x1a.google.protobuf.Timestamp\x12\x12\n\nsummary_id\x18\x03 \x01(\t\x12\x17\n\x0fnum_experiments\x18\x04 \x01(\x03"5\n\x1fCampaignExecutionSummaryRequest\x12\x12\n\nsummary_id\x18\x01 \x01(\t"G\n!CheckExecutionEligibilityResponse\x12\x13\n\x0bis_eligible\x18\x01 \x01(\x08\x12\r\n\x05error\x18\x02 \x01(\t2\xf3\x18\n\x0eAresAutomation\x12`\n\x0fGetAllCampaigns\x12%.ares.services.GetAllCampaignsRequest\x1a&.ares.services.GetAllCampaignsResponse\x12_\n\x11GetSingleCampaign\x12\x1e.ares.services.CampaignRequest\x1a*.ares.datamodel.templates.CampaignTemplate\x12H\n\x0eRemoveCampaign\x12\x1e.ares.services.CampaignRequest\x1a\x16.google.protobuf.Empty\x12L\n\x0eCampaignExists\x12\x1e.ares.services.CampaignRequest\x1a\x1a.google.protobuf.BoolValue\x12P\n\x0bAddCampaign\x12).ares.services.AddOrUpdateCampaignRequest\x1a\x16.google.protobuf.Empty\x12g\n\x0eUpdateCampaign\x12).ares.services.AddOrUpdateCampaignRequest\x1a*.ares.datamodel.templates.CampaignTemplate\x12e\n\x19CheckExecutionEligibility\x12\x16.google.protobuf.Empty\x1a0.ares.services.CheckExecutionEligibilityResponse\x12I\n\x0eGetAllProjects\x12\x16.google.protobuf.Empty\x1a\x1f.ares.services.ProjectsResponse\x12D\n\nGetProject\x12\x1d.ares.services.ProjectRequest\x1a\x17.ares.datamodel.Project\x12F\n\rRemoveProject\x12\x1d.ares.services.ProjectRequest\x1a\x16.google.protobuf.Empty\x12=\n\nAddProject\x12\x17.ares.datamodel.Project\x1a\x16.google.protobuf.Empty\x12A\n\nGetAllTags\x12\x16.google.protobuf.Empty\x1a\x1b.ares.services.TagsResponse\x12@\n\x06AddTag\x12\x19.ares.services.TagRequest\x1a\x1b.ares.services.TagsResponse\x12C\n\tRemoveTag\x12\x19.ares.services.TagRequest\x1a\x1b.ares.services.TagsResponse\x12e\n\x17SetCampaignForExecution\x12\x1e.ares.services.CampaignRequest\x1a*.ares.datamodel.templates.CampaignTemplate\x12W\n\x1cGetCurrentlySelectedCampaign\x12\x16.google.protobuf.Empty\x1a\x1f.ares.services.CampaignResponse\x12M\n\x0eStartExecution\x12#.ares.services.StartCampaignRequest\x1a\x16.google.protobuf.Empty\x12?\n\rStopExecution\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12@\n\x0ePauseExecution\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12A\n\x0fResumeExecution\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12_\n\x19GetAssignedStopConditions\x12\x16.google.protobuf.Empty\x1a*.ares.services.StartStopConditionsResponse\x12M\n\rGetReplanRate\x12\x16.google.protobuf.Empty\x1a$.ares.services.GetReplanRateResponse\x12^\n\x18GetFailedStartConditions\x12\x16.google.protobuf.Empty\x1a*.ares.services.StartStopConditionsResponse\x12}\n#GetPreliminaryFailedStartConditions\x12*.ares.datamodel.templates.CampaignTemplate\x1a*.ares.services.StartStopConditionsResponse\x12`\n\x1eSetNumExperimentsStopCondition\x12&.ares.services.NumExperimentsCondition\x1a\x16.google.protobuf.Empty\x12B\n\rSetReplanRate\x12\x19.ares.services.ReplanRate\x1a\x16.google.protobuf.Empty\x12`\n\x1eSetAnalysisResultStopCondition\x12&.ares.services.AnalysisResultCondition\x1a\x16.google.protobuf.Empty\x12`\n\x16GetActiveStopCondition\x12\x16.google.protobuf.Empty\x1a..ares.services.ExperimentStopConditionResponse\x12P\n\x13RemoveStopCondition\x12!.ares.services.StartStopCondition\x1a\x16.google.protobuf.Empty\x12_\n\x18GetExecutionStatusStream\x12\x16.google.protobuf.Empty\x1a).ares.datamodel.ExperimentExecutionStatus0\x01\x12b\n\x1fGetStartupExecutionStatusStream\x12\x16.google.protobuf.Empty\x1a%.ares.datamodel.CampaignStartupStatus0\x01\x12d\n GetCloseoutExecutionStatusStream\x12\x16.google.protobuf.Empty\x1a&.ares.datamodel.CampaignCloseoutStatus0\x01\x12d\n\x1aGetCampaignExecutionStatus\x12\x16.google.protobuf.Empty\x1a..ares.services.CampaignExecutionStatusResponse\x12c\n\x1fGetCampaignExecutionStateStream\x12\x16.google.protobuf.Empty\x1a&.ares.datamodel.CampaignExecutionState0\x01\x12|\n&GetAvailableCampaignExecutionSummaries\x12\x16.google.protobuf.Empty\x1a:.ares.services.AvailableCampaignExecutionSummariesResponse\x12n\n\x12GetCampaignSummary\x12..ares.services.CampaignExecutionSummaryRequest\x1a(.ares.datamodel.CampaignExecutionSummaryb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_automation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_TAGREQUEST']._serialized_start = 276
    _globals['_TAGREQUEST']._serialized_end = 334
    _globals['_TAGSRESPONSE']._serialized_start = 336
    _globals['_TAGSRESPONSE']._serialized_end = 407
    _globals['_ADDORUPDATECAMPAIGNREQUEST']._serialized_start = 409
    _globals['_ADDORUPDATECAMPAIGNREQUEST']._serialized_end = 499
    _globals['_REQUESTBYID']._serialized_start = 501
    _globals['_REQUESTBYID']._serialized_end = 533
    _globals['_CAMPAIGNREQUEST']._serialized_start = 535
    _globals['_CAMPAIGNREQUEST']._serialized_end = 612
    _globals['_GETALLCAMPAIGNSREQUEST']._serialized_start = 614
    _globals['_GETALLCAMPAIGNSREQUEST']._serialized_end = 657
    _globals['_GETALLCAMPAIGNSRESPONSE']._serialized_start = 659
    _globals['_GETALLCAMPAIGNSRESPONSE']._serialized_end = 743
    _globals['_CAMPAIGNTEMPLATESUMMARY']._serialized_start = 745
    _globals['_CAMPAIGNTEMPLATESUMMARY']._serialized_end = 812
    _globals['_CAMPAIGNRESPONSE']._serialized_start = 814
    _globals['_CAMPAIGNRESPONSE']._serialized_end = 910
    _globals['_STARTCAMPAIGNREQUEST']._serialized_start = 912
    _globals['_STARTCAMPAIGNREQUEST']._serialized_end = 1010
    _globals['_PROJECTREQUEST']._serialized_start = 1012
    _globals['_PROJECTREQUEST']._serialized_end = 1050
    _globals['_PROJECTSRESPONSE']._serialized_start = 1052
    _globals['_PROJECTSRESPONSE']._serialized_end = 1113
    _globals['_CAMPAIGNEXECUTIONSTATUSRESPONSE']._serialized_start = 1115
    _globals['_CAMPAIGNEXECUTIONSTATUSRESPONSE']._serialized_end = 1205
    _globals['_STARTSTOPCONDITIONSRESPONSE']._serialized_start = 1207
    _globals['_STARTSTOPCONDITIONSRESPONSE']._serialized_end = 1302
    _globals['_GETREPLANRATERESPONSE']._serialized_start = 1304
    _globals['_GETREPLANRATERESPONSE']._serialized_end = 1347
    _globals['_STARTSTOPCONDITION']._serialized_start = 1349
    _globals['_STARTSTOPCONDITION']._serialized_end = 1400
    _globals['_REPLANRATE']._serialized_start = 1402
    _globals['_REPLANRATE']._serialized_end = 1434
    _globals['_NUMEXPERIMENTSCONDITION']._serialized_start = 1436
    _globals['_NUMEXPERIMENTSCONDITION']._serialized_end = 1486
    _globals['_EXPERIMENTSTOPCONDITIONRESPONSE']._serialized_start = 1488
    _globals['_EXPERIMENTSTOPCONDITIONRESPONSE']._serialized_end = 1568
    _globals['_ANALYSISRESULTCONDITION']._serialized_start = 1570
    _globals['_ANALYSISRESULTCONDITION']._serialized_end = 1635
    _globals['_AVAILABLECAMPAIGNEXECUTIONSUMMARIESRESPONSE']._serialized_start = 1638
    _globals['_AVAILABLECAMPAIGNEXECUTIONSUMMARIESRESPONSE']._serialized_end = 1770
    _globals['_CAMPAIGNEXECUTIONSUMMARYMETADATA']._serialized_start = 1773
    _globals['_CAMPAIGNEXECUTIONSUMMARYMETADATA']._serialized_end = 1928
    _globals['_CAMPAIGNEXECUTIONSUMMARYREQUEST']._serialized_start = 1930
    _globals['_CAMPAIGNEXECUTIONSUMMARYREQUEST']._serialized_end = 1983
    _globals['_CHECKEXECUTIONELIGIBILITYRESPONSE']._serialized_start = 1985
    _globals['_CHECKEXECUTIONELIGIBILITYRESPONSE']._serialized_end = 2056
    _globals['_ARESAUTOMATION']._serialized_start = 2059
    _globals['_ARESAUTOMATION']._serialized_end = 5246


from templates import parameter_pb2 as _parameter_pb2
from templates import command_metadata_pb2 as _command_metadata_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CommandTemplate(_message.Message):
    __slots__ = ("unique_id", "metadata", "parameters", "index", "user_output_key_map")
    class UserOutputKeyMapEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    USER_OUTPUT_KEY_MAP_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    metadata: _command_metadata_pb2.CommandMetadata
    parameters: _containers.RepeatedCompositeFieldContainer[_parameter_pb2.Parameter]
    index: int
    user_output_key_map: _containers.ScalarMap[str, str]
    def __init__(self, unique_id: _Optional[str] = ..., metadata: _Optional[_Union[_command_metadata_pb2.CommandMetadata, _Mapping]] = ..., parameters: _Optional[_Iterable[_Union[_parameter_pb2.Parameter, _Mapping]]] = ..., index: _Optional[int] = ..., user_output_key_map: _Optional[_Mapping[str, str]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'execution_summary_messages.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import experiment_overview_pb2 as experiment__overview__pb2
from . import command_result_pb2 as command__result__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n execution_summary_messages.proto\x12\x0eares.datamodel\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19experiment_overview.proto\x1a\x14command_result.proto"\xc6\x01\n\rExecutionInfo\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x120\n\x0ctime_started\x18\x02 \x01(\x0b2\x1a.google.protobuf.Timestamp\x121\n\rtime_finished\x18\x03 \x01(\x0b2\x1a.google.protobuf.Timestamp\x12\x10\n\x08timezone\x18\x04 \x01(\t\x12\x18\n\x10localtime_offset\x18\x05 \x01(\tB\x0c\n\n_unique_id"\xbb\x03\n\x18CampaignExecutionSummary\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x0bcampaign_id\x18\x02 \x01(\t\x12H\n\x14experiment_summaries\x18\x03 \x03(\x0b2*.ares.datamodel.ExperimentExecutionSummary\x125\n\x0eexecution_info\x18\x04 \x01(\x0b2\x1d.ares.datamodel.ExecutionInfo\x12\x15\n\rcampaign_name\x18\x05 \x01(\t\x12\x15\n\rcampaign_tags\x18\x06 \x01(\t\x12\x16\n\x0ecampaign_notes\x18\x07 \x01(\t\x12M\n\x19startup_execution_summary\x18\x08 \x01(\x0b2*.ares.datamodel.ExperimentExecutionSummary\x12N\n\x1acloseout_execution_summary\x18\t \x01(\x0b2*.ares.datamodel.ExperimentExecutionSummaryB\x0c\n\n_unique_id"\xab\x02\n\x1aExperimentExecutionSummary\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\rexperiment_id\x18\x02 \x01(\t\x12<\n\x0estep_summaries\x18\x03 \x03(\x0b2$.ares.datamodel.StepExecutionSummary\x125\n\x0eexecution_info\x18\x04 \x01(\x0b2\x1d.ares.datamodel.ExecutionInfo\x12?\n\x13experiment_overview\x18\x05 \x01(\x0b2".ares.datamodel.ExperimentOverview\x12\x1a\n\x12result_output_path\x18\x06 \x01(\tB\x0c\n\n_unique_id"\xc8\x01\n\x14StepExecutionSummary\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07step_id\x18\x02 \x01(\t\x12B\n\x11command_summaries\x18\x03 \x03(\x0b2\'.ares.datamodel.CommandExecutionSummary\x125\n\x0eexecution_info\x18\x04 \x01(\x0b2\x1d.ares.datamodel.ExecutionInfoB\x0c\n\n_unique_id"\xec\x01\n\x17CommandExecutionSummary\x12\x16\n\tunique_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\ncommand_id\x18\x02 \x01(\t\x125\n\x0eexecution_info\x18\x03 \x01(\x0b2\x1d.ares.datamodel.ExecutionInfo\x12-\n\x06result\x18\x04 \x01(\x0b2\x1d.ares.datamodel.CommandResult\x12\x14\n\x0ccommand_name\x18\x05 \x01(\t\x12\x1b\n\x13command_description\x18\x06 \x01(\tB\x0c\n\n_unique_idb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'execution_summary_messages_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_EXECUTIONINFO']._serialized_start = 135
    _globals['_EXECUTIONINFO']._serialized_end = 333
    _globals['_CAMPAIGNEXECUTIONSUMMARY']._serialized_start = 336
    _globals['_CAMPAIGNEXECUTIONSUMMARY']._serialized_end = 779
    _globals['_EXPERIMENTEXECUTIONSUMMARY']._serialized_start = 782
    _globals['_EXPERIMENTEXECUTIONSUMMARY']._serialized_end = 1081
    _globals['_STEPEXECUTIONSUMMARY']._serialized_start = 1084
    _globals['_STEPEXECUTIONSUMMARY']._serialized_end = 1284
    _globals['_COMMANDEXECUTIONSUMMARY']._serialized_start = 1287
    _globals['_COMMANDEXECUTIONSUMMARY']._serialized_end = 1523


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_struct.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11ares_struct.proto\x12\x0eares.datamodel"\x8e\x01\n\nAresStruct\x126\n\x06fields\x18\x01 \x03(\x0b2&.ares.datamodel.AresStruct.FieldsEntry\x1aH\n\x0bFieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12(\n\x05value\x18\x02 \x01(\x0b2\x19.ares.datamodel.AresValue:\x028\x01"\xea\x03\n\tAresValue\x12/\n\nnull_value\x18\x01 \x01(\x0e2\x19.ares.datamodel.NullValueH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x16\n\x0cstring_value\x18\x03 \x01(\tH\x00\x12\x16\n\x0cnumber_value\x18\x04 \x01(\x01H\x00\x12\x15\n\x0bbytes_value\x18\x05 \x01(\x0cH\x00\x129\n\x12string_array_value\x18\x06 \x01(\x0b2\x1b.ares.datamodel.StringArrayH\x00\x129\n\x12number_array_value\x18\x07 \x01(\x0b2\x1b.ares.datamodel.NumberArrayH\x00\x123\n\nlist_value\x18\x08 \x01(\x0b2\x1d.ares.datamodel.AresValueListH\x00\x122\n\x0cstruct_value\x18\t \x01(\x0b2\x1a.ares.datamodel.AresStructH\x00\x12/\n\nunit_value\x18\n \x01(\x0e2\x19.ares.datamodel.UnitValueH\x00\x127\n\x0efunction_value\x18\x0b \x01(\x0b2\x1d.ares.datamodel.FunctionValueH\x00B\x06\n\x04kind"$\n\rFunctionValue\x12\x13\n\x0bfunction_id\x18\x01 \x01(\t"\x1e\n\x0bStringArray\x12\x0f\n\x07strings\x18\x01 \x03(\t"\x1e\n\x0bNumberArray\x12\x0f\n\x07numbers\x18\x02 \x03(\x01":\n\rAresValueList\x12)\n\x06values\x18\x01 \x03(\x0b2\x19.ares.datamodel.AresValue*\x1b\n\tNullValue\x12\x0e\n\nNULL_VALUE\x10\x00*\x1b\n\tUnitValue\x12\x0e\n\nUNIT_VALUE\x10\x00b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_struct_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ARESSTRUCT_FIELDSENTRY']._loaded_options = None
    _globals['_ARESSTRUCT_FIELDSENTRY']._serialized_options = b'8\x01'
    _globals['_NULLVALUE']._serialized_start = 837
    _globals['_NULLVALUE']._serialized_end = 864
    _globals['_UNITVALUE']._serialized_start = 866
    _globals['_UNITVALUE']._serialized_end = 893
    _globals['_ARESSTRUCT']._serialized_start = 38
    _globals['_ARESSTRUCT']._serialized_end = 180
    _globals['_ARESSTRUCT_FIELDSENTRY']._serialized_start = 108
    _globals['_ARESSTRUCT_FIELDSENTRY']._serialized_end = 180
    _globals['_ARESVALUE']._serialized_start = 183
    _globals['_ARESVALUE']._serialized_end = 673
    _globals['_FUNCTIONVALUE']._serialized_start = 675
    _globals['_FUNCTIONVALUE']._serialized_end = 711
    _globals['_STRINGARRAY']._serialized_start = 713
    _globals['_STRINGARRAY']._serialized_end = 743
    _globals['_NUMBERARRAY']._serialized_start = 745
    _globals['_NUMBERARRAY']._serialized_end = 775
    _globals['_ARESVALUELIST']._serialized_start = 777
    _globals['_ARESVALUELIST']._serialized_end = 835


from templates import campaign_template_pb2 as _campaign_template_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from templates import experiment_template_pb2 as _experiment_template_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AnalyzerValidationRequest(_message.Message):
    __slots__ = ("analyzer_id", "experiment_template")
    ANALYZER_ID_FIELD_NUMBER: _ClassVar[int]
    EXPERIMENT_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    analyzer_id: str
    experiment_template: _experiment_template_pb2.ExperimentTemplate
    def __init__(self, analyzer_id: _Optional[str] = ..., experiment_template: _Optional[_Union[_experiment_template_pb2.ExperimentTemplate, _Mapping]] = ...) -> None: ...

class ValidationResponse(_message.Message):
    __slots__ = ("success", "messages")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    success: bool
    messages: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, success: bool = ..., messages: _Optional[_Iterable[str]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_user_type.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14ares_user_type.proto\x12\x0eares.datamodel*+\n\x0cAresUserType\x12\r\n\tAresAdmin\x10\x00\x12\x0c\n\x08AresUser\x10\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_user_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_ARESUSERTYPE']._serialized_start = 40
    _globals['_ARESUSERTYPE']._serialized_end = 83


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'connection/connection_info.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n connection/connection_info.proto\x12\x19ares.datamodel.connection"W\n\x0cInfoResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x18\n\x0bdescription\x18\x03 \x01(\tH\x00\x88\x01\x01B\x0e\n\x0c_descriptionb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'connection.connection_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_INFORESPONSE']._serialized_start = 63
    _globals['_INFORESPONSE']._serialized_end = 150


from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Planner(_message.Message):
    __slots__ = ("unique_id", "planner_name", "description", "version")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    PLANNER_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    planner_name: str
    description: str
    version: str
    def __init__(self, unique_id: _Optional[str] = ..., planner_name: _Optional[str] = ..., description: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...



from planning import planner_service_info_pb2 as _planner_service_info_pb2
from templates import parameter_metadata_pb2 as _parameter_metadata_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlannerAllocation(_message.Message):
    __slots__ = ("unique_id", "planner", "parameter")
    UNIQUE_ID_FIELD_NUMBER: _ClassVar[int]
    PLANNER_FIELD_NUMBER: _ClassVar[int]
    PARAMETER_FIELD_NUMBER: _ClassVar[int]
    unique_id: str
    planner: _planner_service_info_pb2.PlannerServiceInfo
    parameter: _parameter_metadata_pb2.ParameterMetadata
    def __init__(self, unique_id: _Optional[str] = ..., planner: _Optional[_Union[_planner_service_info_pb2.PlannerServiceInfo, _Mapping]] = ..., parameter: _Optional[_Union[_parameter_metadata_pb2.ParameterMetadata, _Mapping]] = ...) -> None: ...



"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_safety_service.proto')
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ares_safety_service.proto\x12\rares.services"\x16\n\x14EmergencyStopRequest"c\n\x15EmergencyStopResponse\x12\x16\n\x0estatus_message\x18\x01 \x01(\t\x122\n\x06status\x18\x02 \x01(\x0e2".ares.services.EmergencyStopStatus*>\n\x13EmergencyStopStatus\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\t\n\x05ERROR\x10\x022v\n\x11AresSafetyService\x12a\n\x14RequestEmergencyStop\x12#.ares.services.EmergencyStopRequest\x1a$.ares.services.EmergencyStopResponseb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_safety_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_EMERGENCYSTOPSTATUS']._serialized_start = 169
    _globals['_EMERGENCYSTOPSTATUS']._serialized_end = 231
    _globals['_EMERGENCYSTOPREQUEST']._serialized_start = 44
    _globals['_EMERGENCYSTOPREQUEST']._serialized_end = 66
    _globals['_EMERGENCYSTOPRESPONSE']._serialized_start = 68
    _globals['_EMERGENCYSTOPRESPONSE']._serialized_end = 167
    _globals['_ARESSAFETYSERVICE']._serialized_start = 233
    _globals['_ARESSAFETYSERVICE']._serialized_end = 351


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 6, 31, 1, '', 'ares_server_info.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16ares_server_info.proto\x12\rares.services\x1a\x1bgoogle/protobuf/empty.proto":\n\x12ServerInfoResponse\x12\x13\n\x0bserver_name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t"b\n\x14ServerStatusResponse\x122\n\rserver_status\x18\x01 \x01(\x0e2\x1b.ares.services.ServerStatus\x12\x16\n\x0estatus_message\x18\x02 \x01(\t*H\n\x0cServerStatus\x12\x08\n\x04IDLE\x10\x00\x12\x08\n\x04BUSY\x10\x01\x12\t\n\x05ERROR\x10\x02\x12\x0c\n\x08STOPPING\x10\x03\x12\x0b\n\x07STOPPED\x10\x042\xb4\x01\n\x0eAresServerInfo\x12J\n\rGetServerInfo\x12\x16.google.protobuf.Empty\x1a!.ares.services.ServerInfoResponse\x12V\n\x15GetServerStatusStream\x12\x16.google.protobuf.Empty\x1a#.ares.services.ServerStatusResponse0\x01b\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ares_server_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals['_SERVERSTATUS']._serialized_start = 230
    _globals['_SERVERSTATUS']._serialized_end = 302
    _globals['_SERVERINFORESPONSE']._serialized_start = 70
    _globals['_SERVERINFORESPONSE']._serialized_end = 128
    _globals['_SERVERSTATUSRESPONSE']._serialized_start = 130
    _globals['_SERVERSTATUSRESPONSE']._serialized_end = 228
    _globals['_ARESSERVERINFO']._serialized_start = 305
    _globals['_ARESSERVERINFO']._serialized_end = 485